// Add mocks here for use in your specs.
// A mock is a simple JavaScript object that you will use to fake data.
var demoUser = {
        name: "Trevor",
        birthdate: "3/2/1977"
    },
    badUser = {
        name: "BadGuy"
    };
